/*
 * UdfBurn's Library
 *
 * Copyright (C) 2020, KylinSoft Co., Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: renpeijia <renpeijia@kylinos.cn>
 *
 */

#ifndef DATACDROM_H
#define DATACDROM_H

#include <QObject>
#include <QProcess>
#include "udfburn_global.h"

class DataCDROMImpl;

namespace UdfBurn {

class UDFBURN_EXPORT DataCDROM : public QObject
{
    Q_OBJECT

public:
    explicit DataCDROM(QString &blockName, QObject *parent = nullptr);
    ~DataCDROM();
public:
    /**
     * @brief 获取光盘信息： 光盘类型、光盘总容量、光盘已使用容量
     * @note 主要用于查询光盘信息，但未返回信息，只是加载到内存中，使用其他getxxx方法获取具体的属性信息。
     *
     *     使用样例：
     *
     *     DataCDROM *p = new DataCDROM("/dev/sr0", this);
     *     p->getCDROMInfo();
     *     // 获取光盘类型
     *     QString discType = p->getCDROMType();
     */
    void getCDROMInfo();

    /**
     * @brief 获取光盘总容量
     * @return 总容量，单位b
     * @note 使用此方法前需要先调用方法getCDROMInfo()
     */
    long getCDROMCapacity();

    /**
     * @brief 获取光盘已使用容量
     * @return 已使用容量，单位b
     * @note 使用此方法前需要先调用方法getCDROMInfo()
     */
    long getCDROMUsedCapacity();

    /**
     * @brief 获取光盘类型
     * @return 光盘类型，形如“DVD+RW”
     * @note 使用此方法前需要先调用方法getCDROMInfo()
     */
    QString getCDROMType();

    /**
     * @brief 获取光盘类型
     * @return 光盘类型，形如“DVD+RW”
     * @note 与方法getCDROMInfo()的区别是，该方法只获取光盘类型
     */
    QString getDiscType();


private:
    DataCDROMImpl * m_impl;
};

}

#endif // DATACDROM_H
